package com.ruoyi.web.controller.login;

import com.google.code.kaptcha.Producer;
import com.ruoyi.basic.domain.YjStore;
import com.ruoyi.basic.mapper.YjStoreMapper;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.JpushClientUtil;
import com.ruoyi.common.utils.sign.Base64;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.system.service.ISysConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.FastByteArrayOutputStream;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * 验证码操作处理
 *
 * @author ruoyi
 */
@RestController
public class CaptchaController
{
    @Resource(name = "captchaProducer")
    private Producer captchaProducer;

    @Resource(name = "captchaProducerMath")
    private Producer captchaProducerMath;

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private ISysConfigService configService;


    /**
     * 生成验证码
     */
    @GetMapping("/captchaImage")
    public AjaxResult getCode() throws IOException
    {
        AjaxResult ajax = AjaxResult.success();
        boolean captchaEnabled = configService.selectCaptchaEnabled();
        ajax.put("captchaEnabled", captchaEnabled);
        if (!captchaEnabled)
        {
            return ajax;
        }

        // 保存验证码信息
        String uuid = IdUtils.simpleUUID();
        String verifyKey = CacheConstants.CAPTCHA_CODE_KEY + uuid;

        String capStr = null, code = null;
        BufferedImage image = null;

        // 生成验证码
        String captchaType = RuoYiConfig.getCaptchaType();
        if ("math".equals(captchaType))
        {
            String capText = captchaProducerMath.createText();
            capStr = capText.substring(0, capText.lastIndexOf("@"));
            code = capText.substring(capText.lastIndexOf("@") + 1);

            image = captchaProducerMath.createImage(capStr);
        }
        else if ("char".equals(captchaType))
        {
            capStr = code = captchaProducer.createText();
            image = captchaProducer.createImage(capStr);
        }
        redisCache.setCacheObject(verifyKey, code, Constants.CAPTCHA_EXPIRATION, TimeUnit.MINUTES);
        // 转换流信息写出
        FastByteArrayOutputStream os = new FastByteArrayOutputStream();
        try
        {
            ImageIO.write(image, "jpg", os);
        }
        catch (IOException e)
        {
            return AjaxResult.error(e.getMessage());
        }
        testBindAlias();
        ajax.put("uuid", uuid);
        ajax.put("img", Base64.encode(os.toByteArray()));
        return ajax;
    }

    public void testBindAlias() {


//        JpushClientUtil.bindAlias("reg_123", "user_888");
//        JpushClientUtil.pushToAll("瑜伽汇","这是java广播消息",null);
//        JpushClientUtil.pushByRegistrationId(Arrays.asList("170976fa8bac0ade1e0"),"瑜伽汇","这是RegistrationId广播消息",null);
//        JpushClientUtil.bindAlias("160a3797c9280401a82","15004070936");
//        JpushClientUtil.pushToUser("15004070936","瑜伽汇","这是Alias消息",null);
//        JpushClientUtil.pushToUsers(Arrays.asList("15004070936","mumu"),"瑜伽汇","瑜伽汇群组推送",null);

//        String msg = String.format(
//                "%s：%s",
//                "普拉提", "课程预约成功！"
//        );
//        Map<String, String> extras=new HashMap<>();
//        extras.put("type","bookCourses");//type推送类型：bookCourses 预约课程 groupMessage群聊消息 privateMessage私信消息
//        extras.put("pagePath","/pages/book/book");//pagePath跳转页面
//        extras.put("bookId","123456789");//bookId预约id
//        JpushClientUtil.pushByRegistrationId(Arrays.asList("160a3797c9280401a82"),"瑜伽汇",msg,extras);
    }

}
